diff --git a/bt5/erp5_simulation/PathTemplateItem/portal_solvers/1/1.xml b/bt5/erp5_simulation/PathTemplateItem/portal_solvers/1/1.xml
index 3b22fa3795e5e160b132467a5d41a41705cb4265..03408845b433a20a91392bc8d942487a97dd5554 100644
--- a/bt5/erp5_simulation/PathTemplateItem/portal_solvers/1/1.xml
+++ b/bt5/erp5_simulation/PathTemplateItem/portal_solvers/1/1.xml
@@ -78,7 +78,7 @@
         </item>
         <item>
             <key> <string>delivery_solver</string> </key>
-            <value> <string>FILO Solver</string> </value>
+            <value> <string>LIFO Solver</string> </value>
         </item>
         <item>
             <key> <string>delivery_solver_id</string> </key>
diff --git a/bt5/erp5_simulation/PortalTypeTemplateItem/portal_types/Quantity%20Split%20Solver.xml b/bt5/erp5_simulation/PortalTypeTemplateItem/portal_types/Quantity%20Split%20Solver.xml
index 31cbc3537804cf8989a3f64af8d8478e99957cc8..afc776f39f72bb1045cc349213855eef5ca469b9 100644
--- a/bt5/erp5_simulation/PortalTypeTemplateItem/portal_types/Quantity%20Split%20Solver.xml
+++ b/bt5/erp5_simulation/PortalTypeTemplateItem/portal_types/Quantity%20Split%20Solver.xml
@@ -32,7 +32,7 @@
             <value>
               <tuple>
                 <string>FIFO Solver</string>
-                <string>FILO Solver</string>
+                <string>LIFO Solver</string>
               </tuple>
             </value>
         </item>
diff --git a/bt5/erp5_simulation/bt/revision b/bt5/erp5_simulation/bt/revision
index f11c82a4cb6cc2e8f3bdf52b5cdeaad4d5bb214e..9a037142aa3c1b4c490e1a38251620f113465330 100644
--- a/bt5/erp5_simulation/bt/revision
+++ b/bt5/erp5_simulation/bt/revision
@@ -1 +1 @@
-9
\ No newline at end of file
+10
\ No newline at end of file
diff --git a/product/ERP5/DeliverySolver/DeliverySolver.py b/product/ERP5/DeliverySolver/DeliverySolver.py
index 01828d7926b0360ba2b73740f26d2ca888b03fdd..5e2778369904b5174ba91f8cafd16ea8fc859c02 100644
--- a/product/ERP5/DeliverySolver/DeliverySolver.py
+++ b/product/ERP5/DeliverySolver/DeliverySolver.py
@@ -40,7 +40,7 @@ class DeliverySolver:
     Can be used to:
 
      * distribute
-     * queue (FIFO, FILO, ...)
+     * queue (FIFO, LIFO, ...)
      * etc
   """
 
diff --git a/product/ERP5/Document/Movement.py b/product/ERP5/Document/Movement.py
index 4c68518b7327376518d81999a74dc9b9f54291ce..db70699b8e473ccce0fb7f698a212143ae1b751f 100644
--- a/product/ERP5/Document/Movement.py
+++ b/product/ERP5/Document/Movement.py
@@ -355,7 +355,7 @@ class Movement(XMLObject, Amount):
 
       For outgoing quantities, it is the responsability of database
       to calculate asset prices based on calculation rules (FIFO,
-      FILO, AVERAGE, etc.).
+      LIFO, AVERAGE, etc.).
     """
     # This is what we use for accounting
     result = self.getSourceTotalAssetPrice()
diff --git a/product/ERP5/Tool/SolverTool.py b/product/ERP5/Tool/SolverTool.py
index 4800505f1079d6ea1409995258d300bb3df4ff3b..c848fcc528eecbc364bb964600085443c3437934 100644
--- a/product/ERP5/Tool/SolverTool.py
+++ b/product/ERP5/Tool/SolverTool.py
@@ -95,7 +95,7 @@ class SolverTool(BaseTool):
     """
     # XXX Hardcoded for now. We need a new registration system for
     # delivery solvers.
-    return ['FIFO', 'FILO', 'MinPrice',]
+    return ['FIFO', 'LIFO', 'MinPrice',]
 
   def getDeliverySolverTranslatedItemList(self, class_name_list=None):
     """
diff --git a/product/ERP5/DeliverySolver/FILO.py b/product/ERP5/DeliverySolver/LIFO.py
similarity index 94%
rename from product/ERP5/DeliverySolver/FILO.py
rename to product/ERP5/DeliverySolver/LIFO.py
index a2a56a64ae239b3afc93b7db4bc61c3402f8d888..533b0b84b3d2a12434835a6ed9ec6bfbed46616a 100644
--- a/product/ERP5/DeliverySolver/FILO.py
+++ b/product/ERP5/DeliverySolver/LIFO.py
@@ -32,16 +32,16 @@ from Products.ERP5Type import interfaces
 
 from FIFO import FIFO
 
-class FILO(FIFO):
+class LIFO(FIFO):
   """
   The FILO solver reduces deliveted quantity by reducing the quantity of
   simulation movements from the first order.
   """
 
   # Declarative interfaces
   zope.interface.implements(interfaces.IDeliverySolver)
 
-  title = 'FILO Solver'
+  title = 'LIFO Solver'
 
   def _getSimulationMovementList(self):
     """
@@ -32,16 +32,16 @@ from Products.ERP5Type import interfaces
   """
-  The FILO solver reduces deliveted quantity by reducing the quantity of
+  The LIFO solver reduces deliveted quantity by reducing the quantity of
   simulation movements from the first order.
   """